import { useUserinfoStore } from "@/stores/UserinfoStore"
import type { EngineContext } from '@/composables/useEngine'
import type { GameInfo, GameInfos, PlayerEdit, Lang, CreateGameStatus } from '@/composables/engine.d'

export async function fetchGameInfo(this: EngineContext): Promise<GameInfo> {
  const userInfoStore = useUserinfoStore()
  return await this.callApi('/api/gameinfo', {
    g: userInfoStore.gameId,
  }) as GameInfo
}

export async function setGameLang(this: EngineContext, lang: string): Promise<void> {
  const userInfoStore = useUserinfoStore()
  await this.callApi('/api/setGameLang', {
    g: userInfoStore.gameId,
    lang,
  })
}

export async function setGameName(this: EngineContext, name: string): Promise<void> {
  const userInfoStore = useUserinfoStore()
  await this.callApi('/api/setGameName', {
    g: userInfoStore.gameId,
    name,
  })
}

export async function savePlayer(this: EngineContext, player: PlayerEdit): Promise<void> {
  const userInfoStore = useUserinfoStore()
  await this.callApi('/api/savePlayer', {
    g: userInfoStore.gameId,
    id: player.id,
    name: player.name,
    score: player.score.toString(),
    authcode: player.authcode,
  })
}

export async function removePlayer(this: EngineContext, id: string): Promise<void> {
  const userInfoStore = useUserinfoStore()
  await this.callApi('/api/removePlayer', {
    g: userInfoStore.gameId,
    id,
  })
}

export async function createGame(this: EngineContext, name: string, teamname: string, lang: Lang): Promise<CreateGameStatus> {
  return await this.callApi('/api/createGame', {
    name,
    teamname,
    lang,
  }) as CreateGameStatus
}

export async function fetchGameInfos(this: EngineContext): Promise<GameInfos> {
  const resp = await this.callApi('/api/games') as { games: GameInfos }
  return resp.games
}

export async function cameo(this: EngineContext, authcode: string): Promise<void> {
  await this.callApi('/api/cameo', {
    code: authcode,
  })
}

export async function logoutCameo(this: EngineContext): Promise<void> {
  await this.callApi('/api/cameo')
}
