package application

import (
	"fmt"
	"path"

	"github.com/google/uuid"
	"sirlab.de/go/knowyt/game"
	"sirlab.de/go/knowyt/user"
)

func (app *Application) createUser(gm *game.Game, name, role, authcode string) (string, error) {
	gameId := ""
	if gm != nil {
		gameId = gm.GetId()
	}

	if authcode != "" {
		if _, err := app.GetUserByAuthcode(authcode); err == nil {
			return "", fmt.Errorf("%s authcode already in use", gameId)
		}
	}

	dirName := path.Join(app.config.DataDir, "users")
	userNewUuid := uuid.NewString()
	fileName := path.Join(dirName, userNewUuid+".json")
	newUser := user.CreateUser(fileName, gameId)
	newUser.SetRole(role)
	newUser.SetName(name)
	newUser.SetAuthcode(authcode)
	if err := newUser.SaveUser(); err != nil {
		return "", err
	}
	app.users[newUser.GetId()] = newUser

	if gm != nil {
		gm.AddPlayer(newUser)
	}

	return newUser.GetId(), nil
}
