package application

import (
	"encoding/json"
	"fmt"
	"net/http"

	"sirlab.de/go/knowyt/log"
	"sirlab.de/go/knowyt/user"
)

func (app *Application) GetGameInfo(usr *user.User, w http.ResponseWriter, r *http.Request) {
	gameRef := r.URL.Query().Get("g")
	gm, err := app.GetGameById(gameRef)
	if err != nil {
		w.WriteHeader(http.StatusNotFound)
		fmt.Fprintf(w, "game not found")
		return
	}

	if usr.GetGameId() != gameRef || !usr.IsGamemaster() {
		w.WriteHeader(http.StatusForbidden)
		fmt.Fprintf(w, "forbidden")
		return
	}

	gameInfo := gm.GetGameInfo()
	for i := range gameInfo.Players {
		if playerUser, err := app.GetUserById(gameInfo.Players[i].Id); err != nil {
			log.Warn("GetUserById() failed: couldn't find player %s\n", gameInfo.Players[i].Id)
			w.WriteHeader(http.StatusInternalServerError)
			fmt.Fprintf(w, "internal server error")
			return
		} else {
			gameInfo.Players[i].AuthCode = playerUser.GetAuthCode()
			gameInfo.Players[i].Created = playerUser.GetCreated()
			gameInfo.Players[i].LastLoggedIn = playerUser.GetLastLoggedIn()
		}
	}

	w.Header().Add("Content-Type", "application/json")
	jsonString, _ := json.Marshal(gameInfo)
	fmt.Fprintf(w, "%s", string(jsonString))
}
