package application

import (
	"encoding/json"
	"fmt"
	"net/http"

	"sirlab.de/go/knowyt/log"
	"sirlab.de/go/knowyt/user"
)

func (app *Application) GetQuotes(usr *user.User, w http.ResponseWriter, r *http.Request) {
	gameRef := r.URL.Query().Get("g")
	gm, err := app.GetGameById(gameRef)
	if err != nil {
		log.Warn("attempt to get quotes for invalid game id %s\n", gameRef)
		w.WriteHeader(http.StatusNotFound)
		fmt.Fprintf(w, "game not found")
		return
	}

	if usr.GetGameId() != gameRef && !usr.IsGamemaster() {
		log.Warn("user's game id is %s\n", usr.GetGameId())
		log.Warn("user not allowed to access game id %s\n", gameRef)
		w.WriteHeader(http.StatusForbidden)
		fmt.Fprintf(w, "forbidden")
		return
	}

	quotesInfo := gm.GetQuotesInfoByUser(usr)
	w.Header().Add("Content-Type", "application/json")
	jsonString, _ := json.Marshal(quotesInfo)
	fmt.Fprintf(w, "%s", string(jsonString))
}
