package application

import (
	"fmt"
	"net/http"
	"path"

	"github.com/google/uuid"
	"sirlab.de/go/knowyt/game"
	"sirlab.de/go/knowyt/log"
	"sirlab.de/go/knowyt/user"
)

func (app *Application) SaveQuote(usr *user.User, w http.ResponseWriter, r *http.Request) {
	gameRef := r.URL.Query().Get("g")
	gm, err := app.GetGameById(gameRef)
	if err != nil {
		w.WriteHeader(http.StatusNotFound)
		fmt.Fprintf(w, "game not found")
		return
	}

	if usr.GetGameId() != gameRef && !usr.IsGamemaster() {
		w.WriteHeader(http.StatusForbidden)
		fmt.Fprintf(w, "forbidden")
		return
	}

	quoteText := r.URL.Query().Get("quote")
	quoteId := r.URL.Query().Get("id")
	if quoteId[:5] == ":new:" {
		if app.debounceQuote(usr.GetId() + ":" + quoteId) {
			quoteNewUuid := uuid.NewString()
			err = gm.CreateQuote(
				app.getQuoteFileNameFromId(gm, quoteNewUuid),
				usr.GetId(),
				quoteNewUuid,
				quoteText,
			)
		}
	} else {
		err = gm.SaveQuote(
			app.getQuoteFileNameFromId(gm, quoteId),
			usr.GetId(),
			quoteId,
			quoteText,
		)
	}

	if err != nil {
		log.ErrorLog(err)
		w.WriteHeader(http.StatusForbidden)
		fmt.Fprintf(w, "forbidden")
		return
	}

	fmt.Fprintf(w, "ok")
}

func (app *Application) getQuoteFileNameFromId(gm *game.Game, id string) string {
	gameDirName := path.Join(app.config.DataDir, "games", gm.GetId())
	quoteFileNameShort := id + ".json"
	return path.Join(gameDirName, "quotes", quoteFileNameShort)
}

func (app *Application) debounceQuote(id string) bool {
	if app.debounceMap[id] {
		return false
	}
	app.debounceMap[id] = true
	return true
}
