package handler

import (
	"fmt"
	"net/http"

	"sirlab.de/go/knowyt/log"
)

func (authMux *AuthMux) createCookie() *http.Cookie {
	return &http.Cookie{
		Name:     "knowyt-auth",
		Path:     "/",
		HttpOnly: true,
		MaxAge:   -1,
		SameSite: http.SameSiteLaxMode,
	}
}

func (authMux *AuthMux) Logout(w http.ResponseWriter, r *http.Request) {
	http.SetCookie(w, authMux.createCookie())

	cameoCookie := authMux.createCookie()
	cameoCookie.Name = cameoCookie.Name + "-cameo"
	http.SetCookie(w, cameoCookie)

	w.Header().Add("Content-Type", "text/plain")
	fmt.Fprintf(w, "ok")
}

func (authMux *AuthMux) Login(w http.ResponseWriter, r *http.Request) {
	usr, err := authMux.checkAuthCode(r)
	if err != nil {
		log.ErrorLog(err)
		http.SetCookie(w, authMux.createCookie())
		authMux.accessDenied(w, r)
		return
	}

	if !usr.IsAdmin() {
		// check, if game is enabled
		gm, err := authMux.app.GetGameById(usr.GetGameId())
		if err != nil || !gm.IsActive() {
			log.ErrorLog(fmt.Errorf("game %s disabled for user %s (%s)", gm.GetId(), usr.GetName(), usr.GetId()))
			http.SetCookie(w, authMux.createCookie())
			authMux.accessDenied(w, r)
			return
		}
	}

	log.Info("%s (%s) logged into game %s\n", usr.GetName(), usr.GetId(), usr.GetGameId())

	tokenString, err := authMux.createToken(usr.GetId())
	if err != nil {
		log.ErrorLog(fmt.Errorf("failed to create JWT for user id %s (%s)", usr.GetName(), usr.GetId()))
		log.ErrorLog(err)
		http.SetCookie(w, authMux.createCookie())
		authMux.accessDenied(w, r)
		return
	}

	cookie := authMux.createCookie()
	cookie.Value = tokenString
	cookie.MaxAge = 0
	http.SetCookie(w, cookie)
	w.Header().Add("Content-Type", "text/plain")
	fmt.Fprintf(w, "ok")
}
