package log

import (
	"fmt"
	"sync"
)

var lock = &sync.Mutex{}
var loglevel = LOG_NONE

func SetLoglevel(_loglevel int) {
	lock.Lock()
	defer lock.Unlock()

	loglevel = _loglevel
}

func logWithPrefix(message string) {
	fmt.Printf("[knowyt] %s", message)
}

func Debug(format string, v ...any) {
	lock.Lock()
	defer lock.Unlock()

	if loglevel >= LOG_DEBUG {
		logWithPrefix(fmt.Sprintf(format, v...))
	}
}

func Info(format string, v ...any) {
	lock.Lock()
	defer lock.Unlock()

	if loglevel >= LOG_INFO {
		logWithPrefix(fmt.Sprintf(format, v...))
	}
}

func Warn(format string, v ...any) {
	lock.Lock()
	defer lock.Unlock()

	if loglevel >= LOG_WARN {
		logWithPrefix(fmt.Sprintf(format, v...))
	}
}

func Error(format string, v ...any) {
	lock.Lock()
	defer lock.Unlock()

	if loglevel >= LOG_ERROR {
		logWithPrefix(fmt.Sprintf(format, v...))
	}
}

func ErrorLog(err error) {
	Error("%v\n", err)
}
